# ApiCat
![GitHub stars](https://img.shields.io/github/stars/xinghai-osc/apicat?style=social.svg?style=social&label=Star)  
## 简介
ApiCat 是一个API框架，它能帮助站长快速部署各种API。
## 使用
### 安装  
运行
```bash
pip install apicat
```
下载APICAT包。
### 初始化。 
进入项目目录，运行
```bash
apicat init
```
后，您的目录下将出现三个文件，
### 运行。 
在项目目录，运行
```bash
apicat start
```
此时，您已成功启动一个空白的API平台。   
下一步：等待编写。